@@ -3,11 +3,18 @@
 
 def plugin_settings(settings):
     """Settings for the notices app"""
-    # Whether to enable the feature or not
-    settings.FEATURES["ENABLE_NOTICES"] = settings.ENV_TOKENS.get("ENABLE_NOTICES", settings.FEATURES["ENABLE_NOTICES"])
     settings.FEATURES["NOTICES_REDIRECT_ALLOWLIST"] = settings.ENV_TOKENS.get(
         "NOTICES_REDIRECT_ALLOWLIST", settings.FEATURES["NOTICES_REDIRECT_ALLOWLIST"]
     )
     settings.FEATURES["NOTICES_DEFAULT_REDIRECT_URL"] = settings.ENV_TOKENS.get(
         "NOTICES_DEFAULT_REDIRECT_URL", settings.FEATURES["NOTICES_DEFAULT_REDIRECT_URL"]
     )
+    settings.FEATURES["NOTICES_FALLBACK_LANGUAGE"] = settings.ENV_TOKENS.get(
+        "NOTICES_FALLBACK_LANGUAGE", settings.FEATURES["NOTICES_FALLBACK_LANGUAGE"]
+    )
+    settings.FEATURES["NOTICES_SNOOZE_HOURS"] = settings.ENV_TOKENS.get(
+        "NOTICES_SNOOZE_HOURS", settings.FEATURES["NOTICES_SNOOZE_HOURS"]
+    )
+    settings.FEATURES["NOTICES_SNOOZE_COUNT_LIMIT"] = settings.ENV_TOKENS.get(
+        "NOTICES_SNOOZE_COUNT_LIMIT", settings.FEATURES["NOTICES_SNOOZE_COUNT_LIMIT"]
+    )
